import os
from os.path import join, basename
from glob import glob
from uuid import uuid4

from osgeo import gdal

from ..util import replace_ext


def output_step(source_dir: os.PathLike, target_dir: os.PathLike, options: dict=None):
    # find out the driver to get the extension
    options = options if options is not None else {}
    frmt = options.get('format', 'GTiff')
    driver = gdal.GetDriverByName(frmt)
    if not driver:
        raise ValueError('Unsupported driver %s' % frmt)
    extension = driver.GetMetadata()['DMD_EXTENSIONS'].split(' ')[0]

    # warp each individual file
    warped_files = []
    for filename in glob(join(source_dir, '*.tif')):
        target_filename = join(target_dir, replace_ext(basename(filename), extension))
        gdal.Warp(target_filename, filename, options=gdal.WarpOptions(
            **options
        ))
        warped_files.append(target_filename)

    if len(warped_files) > 1:
        tmp_filename = join(target_dir, '%s.%s' % (uuid4().hex, extension))
        gdal.Warp(tmp_filename, warped_files, options=gdal.WarpOptions(
            **options
        ))

        # delete old files and rename the combined file to the first filename
        for filename in warped_files:
            os.unlink(filename)
        os.rename(tmp_filename, warped_files[0])
